@@ -1,32 +1,86 @@
-from com import View, msgs
+from com import Dialog, msgs
 from RootDevice import RootDevice
-from NowPlaying import NowPlaying
 from mediabox.StorageBrowser import StorageBrowser
+from ui.Button import Button
 from ui.ImageButton import ImageButton
 from ui.Slider import Slider
 from ui.Toolbar import Toolbar
 from ui.dialog import OptionDialog
+from ui.layout import Arrangement
 from utils import mimetypes
 from utils import logging
 from mediabox import config as mb_config
 from utils.ItemScheduler import ItemScheduler
+import platforms
 from theme import theme
 
+import gobject
 import random
 import time
 
 
-class Navigator(View):
+_LANDSCAPE_ARRANGEMENT = """
+  <arrangement>
+    <widget name="toolbar"
+            x1="-80" y1="0" x2="100%" y2="100%"/>
 
-    ICON = theme.mb_viewer_audio
-    TITLE = "Navigator"
-    PRIORITY = 0
+    <if-visible name="btn_add">
+      <widget name="btn_add"
+              x1="0" y1="0" x2="-80" y2="80"/>
+      <widget name="slider"
+              x1="0" y1="80" x2="40" y2="100%"/>
+      <widget name="browser"
+              x1="40" y1="80" x2="-80" y2="100%"/>
+    </if-visible>
+
+    <if-invisible name="btn_add">
+      <widget name="slider"
+              x1="0" y1="0" x2="40" y2="100%"/>
+      <widget name="browser"
+              x1="40" y1="0" x2="-80" y2="100%"/>
+    </if-invisible>                
+  </arrangement>
+"""
+
+
+_PORTRAIT_ARRANGEMENT = """
+  <arrangement>
+    <widget name="toolbar"
+            x1="0" y1="-80" x2="100%" y2="100%"/>
+
+    <if-visible name="btn_add">
+      <widget name="btn_add"
+              x1="0" y1="0" x2="100%" y2="80"/>
+      <widget name="slider"
+              x1="0" y1="80" x2="40" y2="-80"/>
+      <widget name="browser"
+              x1="40" y1="80" x2="100%" y2="-80"/>
+    </if-visible>
+
+    <if-invisible name="btn_add">
+      <widget name="slider"
+              x1="0" y1="0" x2="40" y2="-80"/>
+      <widget name="browser"
+              x1="40" y1="0" x2="100%" y2="-80"/>
+    </if-invisible>                
+  </arrangement>
+"""
+
+
+class Navigator(Dialog):
+    """
+    Navigator dialog for browsing media.
+    """
 
     def __init__(self):
     
         # the file that is currently playing    
         self.__current_file = None
 
+        # list of files for playing
+        self.__play_files = []
+        self.__play_folder = None
+
         # list for choosing random files from when in shuffle mode
         self.__random_files = []
         
@@ -35,23 +89,21 @@ class Navigator(View):
         
         self.__key_hold_down_timestamp = 0
         self.__skip_letter = False
+        
+        self.__is_portrait = False
 
         # scheduler for creating thumbnails one by one
         self.__tn_scheduler = ItemScheduler()
         
+        self.__root_dev = RootDevice()
+        
     
-        View.__init__(self)
-
-        # now-playing box
-        self.__now_playing_box = NowPlaying()
-        self.__now_playing_box.set_visible(False)
-        self.add(self.__now_playing_box)
-        self.__now_playing_box.connect_clicked(self.__on_click_now_playing)
+        Dialog.__init__(self)
 
         # browser list slider
         self.__browser_slider = Slider(theme.mb_list_slider)
         self.__browser_slider.set_mode(Slider.VERTICAL)
-        self.add(self.__browser_slider)
+        #self.add(self.__browser_slider)
 
         
         # file browser
@@ -66,15 +118,21 @@ class Navigator(View):
         #self.__browser.connect_file_bookmarked(self.__on_bookmark_file)
         self.__browser_slider.connect_button_pressed(
                                     lambda a,b:self.__browser.stop_scrolling())
-        self.add(self.__browser)
+        #self.add(self.__browser)
+
+        # [Add] button
+        self.__btn_add = Button("Add New")
+        self.__btn_add.set_visible(False)
+        self.__btn_add.connect_clicked(self.__on_btn_add)
+        #self.add(self.__btn_add)
 
         # beta version!
-        self.__browser.add_overlay_renderer(self.__render_beta_mark)
+        #self.__browser.add_overlay_renderer(self.__render_beta_mark)
 
 
         # toolbar
         self.__toolbar = Toolbar()
-        self.add(self.__toolbar)
+        #self.add(self.__toolbar)
 
         self.__btn_home = ImageButton(theme.mb_btn_home_1,
                                       theme.mb_btn_home_2)
@@ -84,10 +142,6 @@ class Navigator(View):
                                          theme.mb_btn_history_2)
         self.__btn_history.connect_clicked(self.__on_btn_history)
 
-        self.__btn_prefs = ImageButton(theme.mb_btn_prefs_1,
-                                       theme.mb_btn_prefs_2)
-        self.__btn_prefs.connect_clicked(self.__on_btn_prefs)
-
         self.__btn_bookmarks = ImageButton(theme.mb_btn_bookmark_1,
                                            theme.mb_btn_bookmark_2)
         self.__btn_bookmarks.connect_clicked(self.__on_btn_bookmarks)
@@ -96,18 +150,26 @@ class Navigator(View):
                                       theme.mb_btn_dir_up_2)
         self.__btn_back.connect_clicked(self.__on_btn_back)
 
-        self.__btn_add = ImageButton(theme.mb_btn_add_1,
-                                     theme.mb_btn_add_2)
-        self.__btn_add.set_visible(False)
-        self.__btn_add.connect_clicked(self.__on_btn_add)
 
-       
-        self.__browser.set_root_device(RootDevice())
+        # arrangement
+        self.__arr = Arrangement()
+        self.__arr.connect_resized(self.__update_layout)
+        self.__arr.add(self.__browser_slider, "slider")
+        self.__arr.add(self.__browser, "browser")
+        self.__arr.add(self.__btn_add, "btn_add")
+        self.__arr.add(self.__toolbar, "toolbar")
+        self.add(self.__arr)
 
 
-        # menu
-        self.set_window_menu((None, "Settings", self.__on_menu_settings),
-                             (None, "FM Transmitter", self.__on_menu_fmtx))
+    def __update_layout(self):
+    
+        w, h = self.get_size()
+        if (w < h):
+            # portrait mode
+            self.__arr.set_xml(_PORTRAIT_ARRANGEMENT)
+        else:
+            # landscape mode
+            self.__arr.set_xml(_LANDSCAPE_ARRANGEMENT)
 
 
     def __render_beta_mark(self, screen):
@@ -125,54 +187,104 @@ class Navigator(View):
         cwd = self.__browser.get_current_folder()
         items = [self.__btn_home,
                  self.__btn_history,
-                 self.__btn_prefs,
                  self.__btn_back]
         
-        if (cwd.folder_flags & cwd.ITEMS_ADDABLE):
-            items.append(self.__btn_add)
-
         self.__toolbar.set_toolbar(*items)
 
+
+    def __update_items_per_row(self, folder):
+
+        w, h = self.get_size()
+        
+        if (folder and folder.folder_flags & folder.ITEMS_COMPACT):
+            if (self.__is_portrait):
+                self.__browser.set_items_per_row(2)
+            else:
+                self.__browser.set_items_per_row(4)
+        else:
+            self.__browser.set_items_per_row(1)
             
+        self.__browser.invalidate()
+        #self.__browser.render()
+
+
+
+    """
+    def __update_menu(self):
+        ""
+        Updates the contents of the window menu.
+        ""
+
+        cwd = self.__browser.get_current_folder()
+        opts = []
+        
+        opts.append((None, "Select Output Device", self.__on_menu_select_output))
+        
+        if (cwd.folder_flags & cwd.ITEMS_SORTABLE):
+            opts.append((None, "Rearrange", self.__on_menu_rearrange))
+            
+        opts.append((None, "Info", None))
+        
+        if (platforms.PLATFORM == platforms.MAEMO5):
+            opts.append((None, "FM Transmitter", self.__on_menu_fmtx))
+            
+        self.set_window_menu(*opts)
+    """
+    
+    
+    """
     def show(self):
     
-        View.show(self)
+        SubView.show(self)
         names = [ p.name for p in self.__browser.get_path() ]
         #title = u" \u00bb ".join(names)
         title = names[-1]
         #self.set_title(title)
 
         self.__update_toolbar()
+        #self.__update_menu()
         self.emit_message(msgs.INPUT_EV_CONTEXT_BROWSER)
-
+    """
+    
 
     def _visibility_changed(self):
         
-        View._visibility_changed(self)
+        Dialog._visibility_changed(self)
         if (self.is_visible()):
             self.__tn_scheduler.resume()
         else:
             self.__tn_scheduler.halt()
 
 
-    def __on_menu_settings(self, *args):
+    def __on_menu_select_output(self):
     
-        self.emit_message(msgs.UI_ACT_SELECT_VIEW, "Preferences")
+        self.emit_message(msgs.MEDIA_ACT_SELECT_OUTPUT, None)
+
+
+    def __on_menu_rearrange(self):
+    
+        def on_done():
+            self.__browser.set_drag_sort_enabled(False)
+            self.__update_toolbar()
+    
+        self.__browser.set_drag_sort_enabled(True)
+    
+        btn_done = ImageButton(theme.mb_btn_history_1,
+                               theme.mb_btn_history_2)
+        btn_done.connect_clicked(on_done)
+        self.__toolbar.set_toolbar(btn_done)
         
         
     def __on_menu_fmtx(self):
     
-        pass
-
-    
-    def __on_click_now_playing(self):
-    
-        self.emit_message(msgs.UI_ACT_SELECT_VIEW, "MediaView")
-            
+        import platforms
+        platforms.plugin_execute("libcpfmtx.so")
+          
        
     def __on_open_file(self, f):
-    
+            
         self.__load_file(f)
+        #self.set_visible(False)
 
 
     def __on_begin_folder(self, f):
@@ -180,7 +292,17 @@ class Navigator(View):
         self.__tn_scheduler.new_schedule(5, self.__on_load_thumbnail)
         self.__tn_scheduler.halt()
         
-        self.set_title(f.name)
+        #self.set_title(f.name)
+        self.set_busy(True)
+        
+        if (f.folder_flags & f.ITEMS_ADDABLE):
+            self.__btn_add.set_visible(True)
+        else:
+            self.__btn_add.set_visible(False)
+                       
+        self.__update_layout()
+        self.render()
+        self.__update_items_per_row(f)
 
 
     def __on_progress_folder(self, f, c):
@@ -189,7 +311,7 @@ class Navigator(View):
 
         item = self.__browser.get_items()[-1]
         thumbpath, is_final = \
-          self.call_service(msgs.MEDIASCANNER_SVC_LOOKUP_THUMBNAIL, c)
+          self.call_service(msgs.THUMBNAIL_SVC_LOOKUP_THUMBNAIL, c)
 
         item.set_icon(thumbpath)
         
@@ -199,20 +321,19 @@ class Navigator(View):
 
     def __on_complete_folder(self, f):
 
-        if (self.__browser.is_visible()):
-            names = [ p.name for p in self.__browser.get_path() ]
-            #title = u" \u00bb ".join(names)
-            title = names[-1]
-            names.reverse()
-            acoustic_title = "Entering " + " in ".join(names)
-            #self.set_title(title)
-            self.emit_message(msgs.UI_ACT_TALK, acoustic_title)
-            self.emit_message(msgs.CORE_EV_FOLDER_VISITED, f)
-            self.__update_toolbar()
-        #end if
-        
-        self.__random_files = []
+        self.set_busy(False)
         
+        names = [ p.name for p in self.__browser.get_path() ]
+        #title = u" \u00bb ".join(names)
+        title = names[-1]
+        names.reverse()
+        acoustic_title = "Entering " + " in ".join(names)
+        self.set_title(title)
+        self.emit_message(msgs.UI_ACT_TALK, acoustic_title)
+        self.emit_message(msgs.CORE_EV_FOLDER_VISITED, f)
+        self.__update_toolbar()
+        #self.__update_menu()
+
         if (self.is_visible()):
             self.__tn_scheduler.resume()
 
@@ -262,14 +383,15 @@ class Navigator(View):
     def __on_load_thumbnail(self, item, f):
 
         def on_loaded(thumbpath):
-            self.__update_thumbnail(item, thumbpath)
+            if (thumbpath):
+                self.__update_thumbnail(item, thumbpath)
             
             #if (self.is_visible()):
             self.__tn_scheduler.resume()
     
         # load thumbnail
         self.__tn_scheduler.halt()
-        self.call_service(msgs.MEDIASCANNER_SVC_LOAD_THUMBNAIL, f, on_loaded)
+        self.call_service(msgs.THUMBNAIL_SVC_LOAD_THUMBNAIL, f, on_loaded)
         
 
     def __on_btn_home(self):
@@ -277,6 +399,7 @@ class Navigator(View):
         Reacts on pressing the [Home] button.
         """
 
+        self.emit_message(msgs.SSDP_ACT_SEARCH_DEVICES)
         self.__browser.go_root()
         
         
@@ -290,16 +413,6 @@ class Navigator(View):
             self.__browser.load_folder(f, self.__browser.GO_CHILD, True)
 
 
-    def __on_btn_prefs(self):
-        """
-        Reacts on pressing the [Prefs] button.
-        """
-        
-        f = self.call_service(msgs.CORE_SVC_GET_FILE, "preferences:///")
-        if (f):
-            self.__browser.load_folder(f, self.__browser.GO_CHILD, False)
-
-
     def __on_btn_bookmarks(self):
         """
         Reacts on pressing the [Bookmarks] button.
@@ -316,6 +429,7 @@ class Navigator(View):
         """
 
         self.__browser.go_parent()
+        #self.__update_items_per_row(self.__browser.get_current_folder())
 
             
             
@@ -339,62 +453,45 @@ class Navigator(View):
         Loads the given file.
         """
 
-        self.__current_file = f
-        self.__browser.hilight_file(f)
+        #if (f.mimetype == "application/x-applet"):
+        #    applet_id = f.resource
+        #    self.call_service(msgs.CORE_SVC_LAUNCH_APPLET, applet_id)
 
-        if (f.mimetype == "application/x-applet"):
-            applet_id = f.resource
-            self.call_service(msgs.CORE_SVC_LAUNCH_APPLET, applet_id)
+        if (f.mimetype == f.CONFIGURATOR):
+            cfg_name = f.resource
+            self.emit_message(msgs.UI_ACT_SHOW_DIALOG, cfg_name)
 
         else:
-            if (not f.mimetype in mimetypes.get_image_types()):
-                self.emit_message(msgs.MEDIA_ACT_STOP)
-
-            self.emit_message(msgs.UI_ACT_SELECT_VIEW, "MediaView")
+            #if (not f.mimetype in mimetypes.get_image_types()):
+            self.emit_message(msgs.MEDIA_ACT_STOP)
             self.emit_message(msgs.MEDIA_ACT_LOAD, f)
-            self.emit_message(msgs.MEDIA_EV_LOADED, self, f)
 
+            # update set of play files
+            self.__current_file = f
+            self.__play_files = [ fl for fl in self.__browser.get_files()
+                                  if not fl.mimetype.endswith("-folder") ]
+            self.__play_folder = self.__browser.get_current_folder()
+            self.__random_files = []
+            self.__browser.hilight_file(f)
+
+            self.set_visible(False)
+                    
 
     def render_this(self):
     
         w, h = self.get_size()
-        if (w < h):
-            # portrait mode
-            if (self.__now_playing_box.is_visible()):
-                self.__now_playing_box.set_geometry(0, 0, w, 80)
-                self.__browser_slider.set_geometry(0, 80, 40, h - 70 - 80)
-                self.__browser.set_geometry(40, 80, w - 40, h - 70 - 80)
-            else:
-                self.__browser_slider.set_geometry(0, 0, 40, h - 70)
-                self.__browser.set_geometry(40, 0, w - 40, h - 70)
-            
-            self.__toolbar.set_geometry(0, h - 70, w, 70)
-
-        else:
-            # landscape mode
-            if (self.__now_playing_box.is_visible()):
-                self.__now_playing_box.set_geometry(0, h - 80, w - 70, 80)
-                self.__browser_slider.set_geometry(0, 0, 40, h - 80)
-                self.__browser.set_geometry(40, 0, w - 40 - 70, h - 80)
-            else:
-                self.__browser_slider.set_geometry(0, 0, 40, h)
-                self.__browser.set_geometry(40, 0, w - 40 - 70, h)
-
-            self.__toolbar.set_geometry(w - 70, 0, 70, h)
+        self.__arr.set_geometry(0, 0, w, h)
 
 
     def __go_previous(self):
 
-        playable_files = [ f for f in self.__browser.get_files()
-                           if not f.mimetype.endswith("-folder") ]
-
         try:
-            idx = playable_files.index(self.__current_file)
+            idx = self.__play_files.index(self.__current_file)
         except ValueError:
             return False
             
         if (idx > 0):
-            next_item = playable_files[idx - 1]
+            next_item = self.__play_files[idx - 1]
             self.__load_file(next_item)
             
             
@@ -439,21 +536,19 @@ class Navigator(View):
         
     def __play_next(self, wraparound):
     
-        playable_files = [ f for f in self.__browser.get_files()
-                           if not f.mimetype.endswith("-folder") ]
         try:
-            idx = playable_files.index(self.__current_file)
+            idx = self.__play_files.index(self.__current_file)
         except:
             idx = -1
         
 
-        if (idx + 1 < len(playable_files)):
-            next_item = playable_files[idx + 1]
+        if (idx + 1 < len(self.__play_files)):
+            next_item = self.__play_files[idx + 1]
             self.__load_file(next_item)
             return True
 
         elif (wraparound):
-            next_item = playable_files[0]
+            next_item = self.__play_files[0]
             self.__load_file(next_item)
             return True
             
@@ -469,15 +564,20 @@ class Navigator(View):
             pass
 
         if (not self.__random_files):
-            self.__random_files = [ f for f in self.__browser.get_files()
-                                    if not f.mimetype.endswith("-folder") ]
+            self.__random_files = self.__play_files[:]
 
         idx = random.randint(0, len(self.__random_files) - 1)
         next_item = self.__random_files.pop(idx)
+        print self.__random_files
+        print idx, "->", next_item
         self.__load_file(next_item)
         
         return True
 
+
+    def handle_CORE_EV_THEME_CHANGED(self):
+    
+        self.render()
       
 
     def handle_CORE_EV_FOLDER_INVALIDATED(self, folder):
@@ -507,6 +607,11 @@ class Navigator(View):
             self.__search_term = key
         #end if
 
+    
+    def handle_CORE_EV_APP_STARTED(self):
+
+        gobject.idle_add(self.__browser.set_root_device, self.__root_dev)
+
 
     def handle_CORE_EV_SEARCH_CLOSED(self):
     
@@ -516,31 +621,21 @@ class Navigator(View):
         self.__is_searching = False
         self.__search_term = ""
 
+
+    def handle_ASR_EV_PORTRAIT(self):
+        
+        self.__is_portrait = True
+        self.set_visible(False)
+        self.__update_items_per_row(self.__browser.get_current_folder())
+
+
+    def handle_ASR_EV_LANDSCAPE(self):
+
+        self.__is_portrait = False
+        self.set_visible(False)
+        self.__update_items_per_row(self.__browser.get_current_folder())
+                    
     
-    def handle_MEDIA_EV_LOADED(self, viewer, f):
-    
-        icon, is_final = self.call_service(msgs.MEDIASCANNER_SVC_LOOKUP_THUMBNAIL, f)
-        self.__now_playing_box.set_playing(icon, f)
-        self.__now_playing_box.set_action("Loaded:")
-        self.__now_playing_box.set_visible(True)
-        self.render()
-
-
-    def handle_MEDIA_EV_PLAY(self):
-    
-        self.__now_playing_box.set_action("Playing:")
-
-
-    def handle_MEDIA_EV_PAUSE(self):
-    
-        self.__now_playing_box.set_action("Paused:")
-
-
-    def handle_MEDIA_EV_EOF(self):
-    
-        self.__now_playing_box.set_action("Loaded:")
-
-
     def handle_MEDIA_ACT_PREVIOUS(self):
     
         self.__go_previous()
@@ -649,3 +744,10 @@ class Navigator(View):
         if (self.is_active()):
             self.__browser.go_parent()
 
+
+    def handle_INPUT_EV_MENU(self):
+    
+        #if (self.is_active()):
+        #self.emit_message(msgs.MEDIA_ACT_SELECT_OUTPUT, None)
+        self.emit_message(msgs.UI_ACT_SHOW_DIALOG, "FMTXDialog")
+
