@@ -1,6 +1,6 @@
 from com import Configurator, msgs
 from ui.itemview import ThumbableGridView
-from ui.itemview import LabelItem
+from ui.dialog import InfoDialog
 from ThemeListItem import ThemeListItem
 from mediabox import config
 from theme import theme
@@ -14,7 +14,7 @@ class ConfigTheme(Configurator):
     Configurator for selecting the UI theme.
     """
 
-    ICON = theme.prefs_theme
+    ICON = theme.prefs_icon_theme
     TITLE = "Themes"
     DESCRIPTION = "Change the look of MediaBox with themes"
     
@@ -25,10 +25,7 @@ class ConfigTheme(Configurator):
         
         self.__list = ThumbableGridView()
         self.add(self.__list)
-        
-        title = LabelItem("Select a Theme:")
-        self.__list.append_item(title)
-                  
+                         
         self.__update_list()
         
         
@@ -45,8 +42,9 @@ class ConfigTheme(Configurator):
         self.__list.set_geometry(0, 0, w, h)
         
         
-    def __on_item_clicked(self, preview, name, title):
+    def __on_item_clicked(self, preview, name, title, idx):
     
+        self.__list.set_hilight(idx)
         gobject.idle_add(self.__change_theme, name, title, preview)
 
 
@@ -55,6 +53,7 @@ class ConfigTheme(Configurator):
         w, h = self.get_size()
         themes = theme.list_themes()
         self.__themes = []
+        idx = 0
         for name, preview, title, description, author in themes:
             try:
                 img = gtk.gdk.pixbuf_new_from_file(preview)
@@ -63,25 +62,29 @@ class ConfigTheme(Configurator):
                 
             item = ThemeListItem(img, title, description, author)
             item.set_size(w, 80)
-            item.connect_clicked(self.__on_item_clicked, preview, name, title)
+            item.connect_clicked(self.__on_item_clicked, preview, name, title, idx)
             
-            idx = self.__list.append_item(item)
+            self.__list.append_item(item)
             self.__themes.append((name, title))
             
-            #if (name == config.theme()):
-            #    self.__list.hilight(idx)
+            if (name == config.theme()):
+                self.__list.set_hilight(idx)
+
+            idx += 1
         #end for
 
 
     def __change_theme(self, t, title, preview):
-
-        #self.emit_event(msgs.UI_ACT_SHOW_MESSAGE, "Loading Theme",
-        #                "- %s -" % title, preview)
-        import time; time.sleep(0.5)
-                        
+                       
+        #self.set_visible(False)
+        
+        dlg = InfoDialog(u"Using theme \xbb%s\xab" % title, self)
+        dlg.run()
+        
         config.set_theme(t)
         theme.set_theme(t)
+        self.propagate_theme_change()
+        self.render()
 
-        #self.emit_event(msgs.UI_ACT_HIDE_MESSAGE)
-        self.emit_event(msgs.CORE_EV_THEME_CHANGED)
+        self.emit_message(msgs.CORE_EV_THEME_CHANGED)
 
