@@ -1,5 +1,4 @@
 from ui.itemview.Item import Item
-from mediabox import thumbnail
 from utils import textutils
 from theme import theme
 
@@ -13,17 +12,15 @@ class MediaItem(Item):
 
 
     def __init__(self, f, icon):
-
-        self.__grip_visible = False
-        
+       
         # whether this item is rendered compact
         self.__is_compact = False
 
         self.__file = f
         self.__icon = icon
-        self.__label = textutils.escape_xml(f.name)
+        self.__label = f.name #textutils.escape_xml(f.name)
         self.__letter = self.__label and unicode(self.__label)[0].upper() or " "
-        self.__sublabel = textutils.escape_xml(f.info)
+        self.__sublabel = f.info #textutils.escape_xml(f.info)
 
         Item.__init__(self)
         self.set_size(-1, 100)
@@ -70,12 +67,6 @@ class MediaItem(Item):
         self._invalidate_cached_pixmap()
         
          
-    def set_grip_visible(self, v):
-        
-        self.__grip_visible = v
-        self._invalidate_cached_pixmap()
-        
-
     def set_compact(self, v):
     
         self.__is_compact = v
@@ -104,7 +95,7 @@ class MediaItem(Item):
             pmap.fill_area(0, 0, w, h, theme.color_mb_background)
 
             # render selection frame
-            if (self.is_hilighted()):
+            if (self.is_marked() or self.is_hilighted()):
                 pmap.draw_frame(theme.mb_selection_frame,
                                 4, 0, w - 8, h, True,
                                 pmap.TOP | pmap.BOTTOM | pmap.LEFT | pmap.RIGHT)
@@ -115,7 +106,7 @@ class MediaItem(Item):
             except:
                 pass
             else:
-                pmap.fit_pixbuf(pbuf, 0, 0, w, h - 20)
+                pmap.fit_pixbuf(pbuf, 4, 4, w - 8, h - 32)
                 del pbuf
 
             #pbuf = thumbnail.render_on_pixbuf(self.__icon, self.__file.mimetype)
@@ -133,9 +124,9 @@ class MediaItem(Item):
 
             # render text
             pmap.set_clip_rect(5, 0, w - 10, h)
-            pmap.draw_centered_text(self.__label, theme.font_mb_listitem,
-                                    0, h - 20, w, 20,
-                                    theme.color_mb_listitem_text)
+            pmap.draw_centered_text(self.__label, theme.font_mb_plain,
+                                    5, h - 26, w - 10, 26,
+                                    theme.color_list_item_text)
             pmap.set_clip_rect()
             
         #end if
@@ -152,26 +143,21 @@ class MediaItem(Item):
         pmap, is_new = self._get_cached_pixmap()
         
         if (is_new):
-            #print "FULL RENDER", self.__label
-
-            #if (self.is_marked()):
-            #    pmap.fill_area(0, 0, w, h, "#ff0000")
-            #if (self.is_hilighted()):
-            #    pmap.fill_area(0, 0, w, h, "#0000ff")
-            #else:
             pmap.fill_area(0, 0, w, h, theme.color_mb_background)
 
             # render selection frame
-            if (self.is_hilighted()):
+            if (self.is_marked() or self.is_hilighted()):
                 pmap.draw_frame(theme.mb_selection_frame, 0, 0, w, h, True,
                                 pmap.TOP | pmap.BOTTOM | pmap.LEFT | pmap.RIGHT)
 
             # render grip
-            if (self.__grip_visible):
-                pmap.draw_pixbuf(theme.mb_item_grip, 0, 0)
-                offset = 32
+            if (self.is_draggable()):
+                pmap.draw_pixbuf(theme.mb_item_grip, w - 32, (h - 80) / 2)
+                clip_rect = (0, 0, w - 34, h)
             else:
-                offset = 4
+                clip_rect = (0, 0, w, h)
+            
+            offset = 4
             
             # render icon
             try:
@@ -195,24 +181,24 @@ class MediaItem(Item):
             #    icon = theme.mb_item_fav_1
             #pmap.draw_pixbuf(icon, offset, 0)
             
-            offset += 130
+            offset = 134
             
             # render text
-            pmap.set_clip_rect(0, 0, w - 80, h)
-            pmap.draw_text(self.__label, theme.font_mb_listitem,
+            pmap.set_clip_rect(*clip_rect)
+            pmap.draw_text(self.__label, theme.font_mb_plain,
                            offset, 20,
-                           theme.color_mb_listitem_text)
+                           theme.color_list_item_text)
             pmap.draw_text(self.__sublabel, theme.font_mb_tiny,
-                           offset, h - 40,
-                           theme.color_mb_listitem_subtext)
+                           offset, 40,
+                           theme.color_list_item_subtext)
             pmap.set_clip_rect()
             
             # render button
-            if (self.__file.mimetype.endswith("-folder")):
-                btn = theme.mb_item_btn_open
-            else:
-                btn = theme.mb_item_btn_play
-            pmap.draw_pixbuf(btn, w - 60, (h - 42) / 2)
+            #if (self.__file.mimetype.endswith("-folder")):
+            #    btn = theme.mb_item_btn_open
+            #else:
+            #    btn = theme.mb_item_btn_play
+            #pmap.draw_pixbuf(btn, w - 60, (h - 42) / 2)
         #end if
         
         # copy to the given canvas
@@ -226,15 +212,13 @@ class MediaItem(Item):
         
     def click_at(self, px, py):
     
-        w, h = self.get_size()
-        if (self.__is_compact):
-            self.emit_event(self.EVENT_ACTIVATED)
-        elif (w - 80 <= px <= w):
-            self.emit_event(self.EVENT_ACTIVATED)
+        self.emit_event(self.EVENT_ACTIVATED)
+        #w, h = self.get_size()
+        #if (self.__is_compact):
+        #    self.emit_event(self.EVENT_ACTIVATED)
+        #elif (w - 80 <= px <= w):
+        #    self.emit_event(self.EVENT_ACTIVATED)
 
-        #elif (px < 60):
-        #    self.__file.bookmarked = not self.__file.bookmarked
-            
             
     def tap_and_hold(self, px, py):
     
