@@ -2,7 +2,9 @@
 Class for representing a file or folder on a storage device.
 """
 
-import md5
+import hashlib
+import gobject
+import gtk
 
 
 class File(object):
@@ -22,15 +24,23 @@ class File(object):
     ITEMS_DOWNLOADABLE =   1 << 5
     ITEMS_ADDABLE =        1 << 6
     ITEMS_SORTABLE =       1 << 7
+    ITEMS_SORTED_ALPHA =   1 << 8
+    ITEMS_COMPACT =        1 << 9
     
 
 
     FILE = "application/x-other"
     """MIME type for unknown file types"""
 
+    CONFIGURATOR = "application/x-configurator"
+    """MIME type for configurators"""
+
     DIRECTORY = "application/x-folder"
     """MIME type for folders"""
     
+    DEVICE_ROOT = "application/x-device-folder"
+    """MIME type for device folders"""
+    
 
     def __init__(self, device):
         """
@@ -174,8 +184,8 @@ class File(object):
         """
         Modification time of this file.
         @since: 0.96.5
-        """
-        
+        """      
+
         self.__medium = None
         
         self.child_count = 0
@@ -224,12 +234,27 @@ class File(object):
     """
 
 
+    def __get_bookmarked(self):
+
+        return self.__device.get_bookmarked(self)
+
+    def __set_bookmarked(self, v):
+
+        self.__device.set_bookmarked(self, v)
+
+    bookmarked = property(__get_bookmarked, __set_bookmarked)
+    """
+    bookmark status of the file
+    @since: 0.97
+    """
+
+
     def __get_md5(self):
         
         try:
             return self.__md5
         except:
-            self.__md5 = md5.new(self.full_path).hexdigest()
+            self.__md5 = hashlib.md5(self.full_path).hexdigest()
             return self.__md5
 
     md5 = property(__get_md5)
@@ -317,25 +342,26 @@ class File(object):
         return self.__device.new_file(self)
         
         
-    def delete_file(self, idx):
+    def delete_file(self, f):
         """
-        Deletes the file given by the index number from this folder. This only
+        Deletes the given file  from this folder. This only
         works if the storage device implements the C{delete_file} method.
-        @since: 0.96.5
+        @since: 2009.10.7
         """
 
-        return self.__device.delete_file(self, idx)    
+        return self.__device.delete_file(self, f)
+               
         
+    def get_file_actions(self, f):
+        """
+        Returns a list of actions for the given file in the folder.
+        @since: 2009.10
         
-    def delete(self):
+        @param f: file object
+        @return: list of (icon, action_name, callback) tuples
         """
-        Deletes this file. This only works if the storage device implements
-        the delete method.
-        @since: 0.96
-        @deprecated: use L{delete_file} instead
-        """
-
-        return self.__device.delete(self)
+        
+        return self.__device.get_file_actions(self, f)
         
         
     def get_children(self):
@@ -352,14 +378,14 @@ class File(object):
                 collection.append(f)
             else:
                 finished[0] = True
+                gobject.timeout_add(0, lambda : False)
             return True
     
         finished = [False]
         collection = []
         self.get_children_async(collector)
         while (not finished[0]):
-            import gtk
-            gtk.main_iteration(False)
+            gtk.main_iteration(True)
     
         return collection
 
@@ -431,14 +457,14 @@ class File(object):
         self.__device.keep(self)
 
 
-    def swap(self, idx1, idx2):
+    def shift_file(self, pos, amount):
         """
-        Swaps two files in this folder.
-        @since: 0.96.5
+        Shifts the file at the given position by the given amount.
+        The shifting amount may be positive or negative.
+        @since: 2009.10.20
         
-        @param idx1: index of first file
-        @param idx2: index of second file
+        @param pos: index of file
+        @param amount: shifting amount
         """
         
-        self.__device.swap(self, idx1, idx2)
-
+        self.__device.shift_file(self, pos, amount)
